@@ -72,8 +72,8 @@ void CommentDeleteJob::start()
 
 void CommentDeleteJob::handleReply(const QNetworkReply *reply, const QByteArray &rawData)
 {
-    Q_UNUSED(reply);
-    Q_UNUSED(rawData);
+    Q_UNUSED(reply)
+    Q_UNUSED(rawData)
 
     emitFinished();
 }
